---
name: Feature request
about: Suggest an idea for this project
title: "[FEATURE] "
labels: enhancement
---

<!-- Consider opening an Discussion instead! -->

**Describe the problem, if any, that your feature request is related to**

A clear and concise description of what the problem is.

**Describe the feature you'd like**

A clear and concise description of what you want to happen.

**Describe alternatives, if any, you've considered**

A clear and concise description of any alternative solutions or features you've considered.
